{ config, lib, pkgs, ... }:
{
  imports = [
      ./hardware-configuration.nix
  ];

  boot.loader.systemd-boot.enable      = true;
  boot.loader.efi.canTouchEfiVariables = true;

  nix.settings.experimental-features = [ "nix-command" "flakes" ];

  networking = {
    hostName = "eve-psr-nix0";
    firewall = { 
      allowedTCPPorts = [ 22 80 443 ];
      allowedUDPPorts = [ 22 80 443 ];
    };
  };

  time.timeZone = "America/Chicago";

  services.openssh.enable = true;
  virtualisation.docker   = {
    enable = true;
    liveRestore = false;
  };

  environment.systemPackages = with pkgs; [
    git
    pciutils
    vim
    wget
  ];


  programs.zsh.enable    = true;
  users.defaultUserShell = pkgs.zsh;
  users.users 	         = {
    sezycei = {
      isNormalUser         = true;
      initialPassword      = "bootMaster";
      extraGroups          = [ "wheel" "docker" ];
      packages             = with pkgs; [
        byobu
        tmux
	stack
      ];
    };
    torrent = {
      isNormalUser         = true;
      initialPassword      = "torrentUserTemp";
    };

  };

  # NixBuild.net Configuration
  programs.ssh.extraConfig = ''
    Host eu.nixbuild.net
      PubkeyAcceptedKeyTypes ssh-ed25519
      IdentityFile /home/sezycei/.ssh/nixbuilds
  '';
  
  programs.ssh.knownHosts = {
    nixbuild = {
      hostNames = [ "eu.nixbuild.net" ];
      publicKey = "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIPIQCZc54poJ8vqawd8TraNryQeJnvH1eLpIDgbiqymM";
    };
  };
  
  nix = {
    distributedBuilds = false;
    buildMachines = [
      { hostName = "eu.nixbuild.net";
        system = "x86_64-linux";
        maxJobs = 100;
        supportedFeatures = [ "benchmark" "big-parallel" ];
      }
    ];
  };

  system.stateVersion = "22.11";
}
